navigations
library
Functions
pop (BuildContext context )
→ void
To pop any screen use pop and pass the context as argument
push (BuildContext context , Widget route )
→ Future <Widget ? >
To push another screen on the stack use push and pass the context,Screen /Page /Widget
To push a named or onGenerate route please use pushNamed and pass the context,Route ,arguments if any
pushAndRemoveUntil (BuildContext context , Widget screen )
→ Future <Widget ? >
To clear the stack and push a screen use pushAndRemoveUntil and pass the context,Screen /Page /Widget
To clear the stack and push a named or onGenerate please use pushNamedAndRemoveUntil and pass the context,Route ,arguments if any
pushNamed <T extends Object ? > (BuildContext context , String route , {Object ? arguments })
→ Future <T? >
To push a named or onGenerate route please use pushNamed and pass the context,Route ,arguments if any
pushNamedAndRemoveUntil <T extends Object ? > (BuildContext context , String route , {Object ? arguments })
→ Future <T? >
To clear the stack and push a named or onGenerate please use pushNamedAndRemoveUntil and pass the context,Route ,arguments if any
pushReplacement (BuildContext context , Widget route )
→ Future <Widget ? >
To replace screen on to the stack use pushReplacement and pass the context,Screen /Page /Widget
To replace a named or onGenerate route please use pushReplacementNamed and pass the context,Route ,arguments if any
pushReplacementNamed <T extends Object ? > (BuildContext context , String route , {Object ? arguments })
→ Future <T? >
To replace a named or onGenerate route please use pushReplacementNamed and pass the context,Route ,arguments if any