BigHead class
Constructors
- BigHead()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
accentColor(
BuildContext context) → Color - accentColor gives access to accent color of theme
-
primaryColor(
BuildContext context) → Color - primaryColor gives access to primary color of theme
-
scaffoldColor(
BuildContext context) → Color - scaffoldColor gives access to scaffold color of theme
-
screenHeight(
BuildContext context) → double - screenHeight provides the current screen height.
-
screenPaddingBottom(
BuildContext context) → double - screenPaddingBottom provides the screen padding from the bottom
-
screenPaddingLeft(
BuildContext context) → double - screenPaddingLeft provides the screen padding from the left
-
screenPaddingRight(
BuildContext context) → double - screenPaddingRight provides the screen padding from the right
-
screenPaddingTop(
BuildContext context) → double - screenPaddingTop provides the current screen padding from the top
-
screenWidth(
BuildContext context) → double - screenWidth provides the current screen width.
-
sizedBoxHeight(
double height) → SizedBox - sizedBoxHeight helps you to create a space between to widgets vertically just pass any double value as the parameter Note: No child widget can be provided to this sizedBoxHeight. if you want to use child widget please refer to SizedBox
-
sizedBoxWidth(
double width) → SizedBox - sizedBoxHeight helps you to create a space between to widgets horizontally just pass any double value as the parameter Note: No child widget can be provided to this sizedBoxWidth . if you want to use child widget please refer to SizedBox
-
textTheme(
BuildContext context) → TextTheme - textTheme this will help you to access any predefined text themes
-
theme(
BuildContext context) → ThemeData - theme is called to access all the theme data. Note: if you want to use textTheme from in theme data prefer textTheme if you want to use primary color you can call primaryColor same as for accentColor and scaffoldColor